/* ====================================================================
 * OpenCMS Lucene Search Engine Integration
 * Copyright (C) 2002 AP Soft Ltd.
 * http:// www.apsoft.ch
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ====================================================================
*/

import java.util.*;
import java.io.*;

public class BatchPdfExtractor {
	
	private String m_batchFile;
	private String m_outputDir;
	
	
	private boolean runBatch(String pdfFile) {
      
		String str;
		String batchFile = m_batchFile + " " + pdfFile + " " + m_outputDir;
		Runtime run = Runtime.getRuntime();
		try {
			Process process = run.exec(batchFile);
			// handle process output
			BufferedReader br = new BufferedReader(new InputStreamReader(process.getInputStream()));
			while (null != (str = br.readLine()))
				; // ignore process output
			if (br != null) br.close();
			// wait for process termination
			process.waitFor();
			return true;
		}
		catch(IOException e ) {
			System.out.println("Error while executing the process : " + e );
			return false;
		}
		catch(InterruptedException e) {
			System.out.println("Error while executing the process : " + e );
			return false;
		}
	}
	
	private String getContent (String htmlFile) {

		String lineStr;
		FileReader fr = null;
		
		try {
			fr = new FileReader(htmlFile);
			BufferedReader bfr = new BufferedReader(fr);
			StringBuffer content = new StringBuffer();
			while ((lineStr = bfr.readLine()) != null) {
				content.append(lineStr + "\n");
			}
			return content.toString();
		}
		catch(IOException e ) {
			System.out.println("IOException: " + e);
			return null;
		}
		finally {
			try {
				if (fr != null) fr.close();
			}
			catch(IOException e) {
			}
		}
	}

	private String buildOutputFileName(String pdfFile) {
		
		int end = pdfFile.toLowerCase().lastIndexOf(".pdf");
		int start = pdfFile.lastIndexOf(File.separatorChar);
		
		if (start == -1)
			start = 0;
		if (end == -1)
			end = pdfFile.length();
		
		return m_outputDir + pdfFile.substring(start, end) + ".html";
	}
	
	public String extractText(String pdfFile, String batchFile, String outputDir) {

		String content = null;
		m_batchFile = batchFile;
		m_outputDir = outputDir;
		
		if (runBatch(pdfFile)) {
			content = getContent(buildOutputFileName(pdfFile));
		}
		return content;
	}
	
	// tester main
	public static void main (String args[]) {
		
		if (args.length < 3) {
			System.out.println("Missing arguments!");
			System.out.println("USAGE: BatchPdfExtractor pdfFile batchFile outputDir");
			return;
		}
		
		BatchPdfExtractor app = new BatchPdfExtractor();
		System.out.println(app.extractText(args[0],args[1], args[2]));
	}
}