/* ====================================================================
 * OpenCMS Lucene Search Engine Integration
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ====================================================================
*/

import java.util.*;
import com.etymon.pj.*;
import com.etymon.pj.object.*;
import com.etymon.pj.exception.*;

public class PdfExtractor {
	
	// tester main
	public static void main (String args[]) {
		
		PdfExtractor app = new PdfExtractor();
		System.out.println(app.extractText(args[0])); 
	}
 
	public String extractText(String pdfFile) {
		
		String extractedText = "";
		
		try {
			Pdf pdf = new Pdf(pdfFile);
			int pages = pdf.getPageCount();

			for (int i = 1; i <= pages; i++) {
				extractedText += getPageContent(pdf, i);
			}
		}
	 	catch (java.io.IOException ex) {
	 		    System.out.println(ex.getMessage());
	 	}
	 	catch (com.etymon.pj.exception.PjException  ex) {
	 		    System.out.println(ex.getMessage());
	 	}
		return extractedText;
	}
	 
	
	private String getPageContent(Pdf pdf, int pageNo)
	    {
	        String content = "";
	        PjStream stream = null;
	        StringBuffer strbf = new StringBuffer();
	        try
	        {
	            PjPage page = (PjPage) pdf.getObject(pdf.getPage(pageNo));
	            PjObject pobj = (PjObject) pdf.resolve(page.getContents());
	            if (pobj instanceof PjArray)
	            {
	                PjArray array = (PjArray) pobj;
	                Vector vArray = array.getVector();
	                int size = vArray.size();
	                for (int j = 0; j < size; j++)
	                {
	                    stream = (PjStream) pdf.resolve((PjObject)
	                    vArray.get(j));
	                    strbf.append(getStringFromPjStream(stream));
	                }
	                content = strbf.toString();
	            }
	            else if (pobj instanceof PjStream)
	            {
	                stream = (PjStream) pobj;
	                content = getStringFromPjStream(stream);
	            }
				else {
					System.out.println("Ignored: " + pobj.getClass().getName());
				}
	        }
	        catch (InvalidPdfObjectException pdfe)
	        {
	            System.out.println("Invalid PDF Object:" + pdfe.getMessage());
	        }
	        catch (Exception e)
	        {
	            System.out.println("Exception in getContent() " + e.getMessage());
	        }
	        return content;
	    }

		private int findNext(String tag, String longString, int pos) {
			int newPos;
			do {
				newPos = longString.indexOf(tag, pos);
				pos = newPos + 1;
			} while (newPos != -1 && longString.charAt(newPos - 1) == '\\');
			return newPos;
		}
			
	    private String getStringFromPjStream(PjStream stream)
	    {
	        StringBuffer strbf = new StringBuffer();
	        try
	        {
	            stream = stream.flateDecompress();
				String longString = stream.toString();
	
	            int start = findNext("(", longString, 0);
				int end = findNext(")", longString, start);
	            while (start != -1 && end != -1)
	            {
	                String text = longString.substring(start + 1, end);
					start = findNext("(", longString, end);
	                end = findNext(")", longString, start);
	                strbf.append(text);
	            }
	        }
	        catch (InvalidPdfObjectException pdfe)
	        {
	            System.out.println("InvalidObjectException:" + pdfe.getMessage());
	        }
	        return strbf.toString();
	    }
}